Low-level FFI bindings to libkrun
This crate provides raw, unsafe bindings to the libkrun C library. For a safe, idiomatic Rust API, use the higher-level wrapper in the boxlite crate.
Constants
- KRUN_
DISK_ FORMAT_ QCOW2 - KRUN_
DISK_ FORMAT_ RAW - KRUN_
LOG_ LEVEL_ DEBUG - KRUN_
LOG_ LEVEL_ ERROR - KRUN_
LOG_ LEVEL_ INFO - KRUN_
LOG_ LEVEL_ OFF - KRUN_
LOG_ LEVEL_ TRACE - KRUN_
LOG_ LEVEL_ WARN - KRUN_
LOG_ STYLE_ ALWAYS - KRUN_
LOG_ STYLE_ AUTO - KRUN_
LOG_ STYLE_ NEVER - KRUN_
LOG_ TARGET_ DEFAULT - KRUN_
LOG_ TARGET_ STDERR - KRUN_
LOG_ TARGET_ STDOUT
Functions
- krun_
add_ ⚠disk - krun_
add_ ⚠disk2 - krun_
add_ ⚠net_ unixgram - krun_
add_ ⚠net_ unixstream - krun_
add_ ⚠virtiofs - krun_
add_ ⚠vsock_ port2 - krun_
create_ ⚠ctx - krun_
free_ ⚠ctx - krun_
init_ ⚠log - krun_
set_ ⚠console_ output - Set a file path to redirect the console output to.
- krun_
set_ ⚠env - krun_
set_ ⚠exec - krun_
set_ ⚠gpu_ options - krun_
set_ ⚠kernel - krun_
set_ ⚠log_ level - krun_
set_ ⚠nested_ virt - krun_
set_ ⚠port_ map - krun_
set_ ⚠rlimits - krun_
set_ ⚠root - krun_
set_ ⚠root_ disk_ remount - Configure a root filesystem backed by a block device with automatic remount.
- krun_
set_ ⚠vm_ config - krun_
set_ ⚠workdir - krun_
setgid ⚠ - Set the gid before starting the microVM.
- krun_
setuid ⚠ - Set the uid before starting the microVM. This allows virtiofsd to run with CAP_SETUID for proper ownership handling.
- krun_
split_ ⚠irqchip - krun_
start_ ⚠enter